summaryrefslogtreecommitdiff
path: root/interfaces.py
diff options
context:
space:
mode:
authorDavid Douard <david.douard@logilab.fr>2013-06-17 15:06:48 +0200
committerDavid Douard <david.douard@logilab.fr>2013-06-17 15:06:48 +0200
commit34e999fc8d56fdeadda39bb8f7122e203af7d869 (patch)
tree85c406f60ea59578241ac0959591720d07fa0fda /interfaces.py
parentb4a281669859719bf13e01b81c6d979fcc0ea2d7 (diff)
downloadpylint-34e999fc8d56fdeadda39bb8f7122e203af7d869.tar.gz
astng has been renamed astroid
Diffstat (limited to 'interfaces.py')
-rw-r--r--interfaces.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/interfaces.py b/interfaces.py
index a24e36f..f3f7591 100644
--- a/interfaces.py
+++ b/interfaces.py
@@ -43,10 +43,10 @@ class IRawChecker(IChecker):
"""interface for checker which need to parse the raw file
"""
- def process_module(self, astng):
+ def process_module(self, astroid):
""" process a module
the module's content is accessible via astng.file_stream
"""
@@ -59,7 +59,7 @@ class ITokenChecker(IChecker):
"""
-class IASTNGChecker(IChecker):
+class IAstroidChecker(IChecker):
""" interface for checker which prefers receive events according to
statement type
"""
@@ -75,7 +75,7 @@ class ILinter(Interface):
def register_checker(self, checker):
"""register a new checker class
checker is a class implementing IrawChecker or / and IASTNGChecker
"""
def add_message(self, msg_id, line=None, node=None, args=None):
@@ -83,7 +83,7 @@ class ILinter(Interface):
If provided, msg is expanded using args
astng checkers should provide the node argument,
raw checkers should provide the line argument.
"""
@@ -43,10 +43,10 @@ class IRawChecker(IChecker):
""" process a module
- the module's content is accessible via astng.file_stream
+ the module's content is accessible via astroid.file_stream
"""
@@ -75,7 +75,7 @@ class ILinter(Interface):
def register_checker(self, checker):
"""register a new checker class
- checker is a class implementing IrawChecker or / and IASTNGChecker
+ checker is a class implementing IrawChecker or / and IAstroidChecker
"""
def add_message(self, msg_id, line=None, node=None, args=None):
@@ -83,7 +83,7 @@ class ILinter(Interface):
If provided, msg is expanded using args
- astng checkers should provide the node argument,
+ astroid checkers should provide the node argument,
raw checkers should provide the line argument.
"""